pub async fn get_agent_by_ca(
agent: &SolanaAgentKit,
contract_address: &str,
interval: Option<u32>,
) -> Result<Value, Box<dyn Error>>Expand description
Retrieve agent details in specified interval by one of its tokens contract address.
Parameters
agent: An instance ofSolanaAgentKit.contract_address: Contract address of one of the tokens contracts (matches case insensitive)interval: An optional Interval for twitter stats and deltas (_3Days, _7Days). If not provided, returns the _7Days.
Returns
A Result that agent details