pub async fn get_agent_by_name(
agent: &SolanaAgentKit,
twitter_name: &str,
interval: Option<u32>,
) -> Result<Value, Box<dyn Error>>Expand description
Retrieve agent details in specified interval by twitter username.
Parameters
agent: An instance ofSolanaAgentKit.twitter_name: Twitter username of agent (matches case insensitive)interval: An optional Interval for twitter stats and deltas (_3Days, _7Days). If not provided, returns the _7Days.
Returns
A Result that agent details