search_tweets

Function search_tweets 

pub async fn search_tweets(
    agent: &SolanaAgentKit,
    tweets: &str,
    from: &str,
    to: &str,
) -> Result<Value, Box<dyn Error>>
Retrieve popular content matching search query, created in time range {from} - {to} (YYYY-MM-DD dates).

Parameters

  • agent: An instance of SolanaAgentKit.
  • search_query: Word or phrase to be searched for in text
  • from: Only consider content created after given date, eg. 2025-01-01
  • to: Only consider content created before given date, eg. 2025-01-20

Returns

A Result that tweets details