pub async fn search_tweets(
agent: &SolanaAgentKit,
tweets: &str,
from: &str,
to: &str,
) -> Result<Value, Box<dyn Error>>Expand description
Retrieve popular content matching search query, created in time range {from} - {to} (YYYY-MM-DD dates).
Parameters
agent: An instance ofSolanaAgentKit.search_query: Word or phrase to be searched for in textfrom: Only consider content created after given date, eg. 2025-01-01to: Only consider content created before given date, eg. 2025-01-20
Returns
A Result that tweets details